# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: pubkey.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import osmopy.interfaces.gogo_pb2 as gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='pubkey.proto',
  package='cosmos.crypto.secp256k1',
  syntax='proto3',
  serialized_options=b'Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256k1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0cpubkey.proto\x12\x17\x63osmos.crypto.secp256k1\x1a\ngogo.proto\"\x1b\n\x06PubKey\x12\x0b\n\x03key\x18\x01 \x01(\x0c:\x04\x98\xa0\x1f\x00\x42\x34Z2github.com/cosmos/cosmos-sdk/crypto/keys/secp256k1b\x06proto3'
  ,
  dependencies=[gogo__pb2.DESCRIPTOR,])




_PUBKEY = _descriptor.Descriptor(
  name='PubKey',
  full_name='cosmos.crypto.secp256k1.PubKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='cosmos.crypto.secp256k1.PubKey.key', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\230\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=53,
  serialized_end=80,
)

DESCRIPTOR.message_types_by_name['PubKey'] = _PUBKEY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PubKey = _reflection.GeneratedProtocolMessageType('PubKey', (_message.Message,), {
  'DESCRIPTOR' : _PUBKEY,
  '__module__' : 'pubkey_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.crypto.secp256k1.PubKey)
  })
_sym_db.RegisterMessage(PubKey)


DESCRIPTOR._options = None
_PUBKEY._options = None
# @@protoc_insertion_point(module_scope)



import hashlib

import bech32
import ecdsa
import hdwallets
import mnemonic

from osmopy._typing import Wallet

DEFAULT_DERIVATION_PATH = "m/44'/118'/0'/0/0"

def generate_wallet() -> Wallet:
    while True:
        phrase = mnemonic.Mnemonic(language="english").generate(strength=256)
        try:
            privkey = seed_to_privkey(phrase)
            break
        except hdwallets.BIP32DerivationError:
            pass
    pubkey = privkey_to_pubkey(privkey)
    address = pubkey_to_address(pubkey)
    return {
        "seed": phrase,
        "derivation_path": DEFAULT_DERIVATION_PATH,
        "private_key": privkey,
        "public_key": pubkey,
        "address": address,
    }


def seed_to_privkey(seed: str, path: str = DEFAULT_DERIVATION_PATH) -> bytes:
    """Get a private key from a mnemonic seed and a derivation path.

    Assumes a BIP39 mnemonic seed with no passphrase. Raises
    `hdwallets.BIP32DerivationError` if the resulting private key is
    invalid.
    """
    seed_bytes = mnemonic.Mnemonic.to_seed(seed, passphrase="")
    hd_wallet = hdwallets.BIP32.from_seed(seed_bytes)
    # This can raise a `hdwallets.BIP32DerivationError`
    derived_privkey = hd_wallet.get_privkey_from_path(path)

    return derived_privkey


def privkey_to_pubkey(privkey: bytes) -> bytes:
    privkey_obj = ecdsa.SigningKey.from_string(privkey, curve=ecdsa.SECP256k1)
    pubkey_obj = privkey_obj.get_verifying_key()
    return pubkey_obj.to_string("compressed")


def pubkey_to_address(pubkey: bytes) -> str:
    s = hashlib.new("sha256", pubkey).digest()
    r = hashlib.new("ripemd160", s).digest()
    five_bit_r = bech32.convertbits(r, 8, 5)
    assert five_bit_r is not None, "Unsuccessful bech32.convertbits call"
    return bech32.bech32_encode('osmo', five_bit_r)

def address_to_address(address: str, prefix: str) -> str:
    five_bit_r = bech32.bech32_decode(address)[1]
    return bech32.bech32_encode(prefix, five_bit_r)

def privkey_to_address(privkey: bytes) -> str:
    pubkey = privkey_to_pubkey(privkey)
    return pubkey_to_address(pubkey)



import sys

if sys.version_info < (3, 8):
    from typing_extensions import Literal, TypedDict
else:
    from typing import Literal, TypedDict


# Valid transaction broadcast modes for the `POST /txs` endpoint of the
# Cyber REST API.
SyncMode = Literal["broadcast_tx_sync", "broadcast_tx_async", "broadcast_tx_commit"]


class Wallet(TypedDict):
    seed: str
    derivation_path: str
    private_key: bytes
    public_key: bytes
    address: str



from osmopy._transaction import Transaction as Transaction  # noqa: F401
from osmopy._wallet import generate_wallet as generate_wallet  # noqa: F401
from osmopy._wallet import privkey_to_address as privkey_to_address  # noqa: F401
from osmopy._wallet import privkey_to_pubkey as privkey_to_pubkey  # noqa: F401
from osmopy._wallet import pubkey_to_address as pubkey_to_address  # noqa: F401
from osmopy._wallet import seed_to_privkey as seed_to_privkey  # noqa: F401
from osmopy._wallet import address_to_address as address_to_address  # noqa: F401
__path__ = __import__('pkgutil').extend_path(__path__, __name__)

__version__ = "1.0.6"  # DO NOT EDIT THIS LINE MANUALLY. LET bump2version UTILITY DO IT


# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gogo.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='gogo.proto',
  package='gogoproto',
  syntax='proto2',
  serialized_options=b'\n\023com.google.protobufB\nGoGoProtosZ\"github.com/gogo/protobuf/gogoproto',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\ngogo.proto\x12\tgogoproto\x1a google/protobuf/descriptor.proto:;\n\x13goproto_enum_prefix\x12\x1c.google.protobuf.EnumOptions\x18\xb1\xe4\x03 \x01(\x08:=\n\x15goproto_enum_stringer\x12\x1c.google.protobuf.EnumOptions\x18\xc5\xe4\x03 \x01(\x08:5\n\renum_stringer\x12\x1c.google.protobuf.EnumOptions\x18\xc6\xe4\x03 \x01(\x08:7\n\x0f\x65num_customname\x12\x1c.google.protobuf.EnumOptions\x18\xc7\xe4\x03 \x01(\t:0\n\x08\x65numdecl\x12\x1c.google.protobuf.EnumOptions\x18\xc8\xe4\x03 \x01(\x08:A\n\x14\x65numvalue_customname\x12!.google.protobuf.EnumValueOptions\x18\xd1\x83\x04 \x01(\t:;\n\x13goproto_getters_all\x12\x1c.google.protobuf.FileOptions\x18\x99\xec\x03 \x01(\x08:?\n\x17goproto_enum_prefix_all\x12\x1c.google.protobuf.FileOptions\x18\x9a\xec\x03 \x01(\x08:<\n\x14goproto_stringer_all\x12\x1c.google.protobuf.FileOptions\x18\x9b\xec\x03 \x01(\x08:9\n\x11verbose_equal_all\x12\x1c.google.protobuf.FileOptions\x18\x9c\xec\x03 \x01(\x08:0\n\x08\x66\x61\x63\x65_all\x12\x1c.google.protobuf.FileOptions\x18\x9d\xec\x03 \x01(\x08:4\n\x0cgostring_all\x12\x1c.google.protobuf.FileOptions\x18\x9e\xec\x03 \x01(\x08:4\n\x0cpopulate_all\x12\x1c.google.protobuf.FileOptions\x18\x9f\xec\x03 \x01(\x08:4\n\x0cstringer_all\x12\x1c.google.protobuf.FileOptions\x18\xa0\xec\x03 \x01(\x08:3\n\x0bonlyone_all\x12\x1c.google.protobuf.FileOptions\x18\xa1\xec\x03 \x01(\x08:1\n\tequal_all\x12\x1c.google.protobuf.FileOptions\x18\xa5\xec\x03 \x01(\x08:7\n\x0f\x64\x65scription_all\x12\x1c.google.protobuf.FileOptions\x18\xa6\xec\x03 \x01(\x08:3\n\x0btestgen_all\x12\x1c.google.protobuf.FileOptions\x18\xa7\xec\x03 \x01(\x08:4\n\x0c\x62\x65nchgen_all\x12\x1c.google.protobuf.FileOptions\x18\xa8\xec\x03 \x01(\x08:5\n\rmarshaler_all\x12\x1c.google.protobuf.FileOptions\x18\xa9\xec\x03 \x01(\x08:7\n\x0funmarshaler_all\x12\x1c.google.protobuf.FileOptions\x18\xaa\xec\x03 \x01(\x08:<\n\x14stable_marshaler_all\x12\x1c.google.protobuf.FileOptions\x18\xab\xec\x03 \x01(\x08:1\n\tsizer_all\x12\x1c.google.protobuf.FileOptions\x18\xac\xec\x03 \x01(\x08:A\n\x19goproto_enum_stringer_all\x12\x1c.google.protobuf.FileOptions\x18\xad\xec\x03 \x01(\x08:9\n\x11\x65num_stringer_all\x12\x1c.google.protobuf.FileOptions\x18\xae\xec\x03 \x01(\x08:<\n\x14unsafe_marshaler_all\x12\x1c.google.protobuf.FileOptions\x18\xaf\xec\x03 \x01(\x08:>\n\x16unsafe_unmarshaler_all\x12\x1c.google.protobuf.FileOptions\x18\xb0\xec\x03 \x01(\x08:B\n\x1agoproto_extensions_map_all\x12\x1c.google.protobuf.FileOptions\x18\xb1\xec\x03 \x01(\x08:@\n\x18goproto_unrecognized_all\x12\x1c.google.protobuf.FileOptions\x18\xb2\xec\x03 \x01(\x08:8\n\x10gogoproto_import\x12\x1c.google.protobuf.FileOptions\x18\xb3\xec\x03 \x01(\x08:6\n\x0eprotosizer_all\x12\x1c.google.protobuf.FileOptions\x18\xb4\xec\x03 \x01(\x08:3\n\x0b\x63ompare_all\x12\x1c.google.protobuf.FileOptions\x18\xb5\xec\x03 \x01(\x08:4\n\x0ctypedecl_all\x12\x1c.google.protobuf.FileOptions\x18\xb6\xec\x03 \x01(\x08:4\n\x0c\x65numdecl_all\x12\x1c.google.protobuf.FileOptions\x18\xb7\xec\x03 \x01(\x08:<\n\x14goproto_registration\x12\x1c.google.protobuf.FileOptions\x18\xb8\xec\x03 \x01(\x08:7\n\x0fmessagename_all\x12\x1c.google.protobuf.FileOptions\x18\xb9\xec\x03 \x01(\x08:=\n\x15goproto_sizecache_all\x12\x1c.google.protobuf.FileOptions\x18\xba\xec\x03 \x01(\x08:;\n\x13goproto_unkeyed_all\x12\x1c.google.protobuf.FileOptions\x18\xbb\xec\x03 \x01(\x08::\n\x0fgoproto_getters\x12\x1f.google.protobuf.MessageOptions\x18\x81\xf4\x03 \x01(\x08:;\n\x10goproto_stringer\x12\x1f.google.protobuf.MessageOptions\x18\x83\xf4\x03 \x01(\x08:8\n\rverbose_equal\x12\x1f.google.protobuf.MessageOptions\x18\x84\xf4\x03 \x01(\x08:/\n\x04\x66\x61\x63\x65\x12\x1f.google.protobuf.MessageOptions\x18\x85\xf4\x03 \x01(\x08:3\n\x08gostring\x12\x1f.google.protobuf.MessageOptions\x18\x86\xf4\x03 \x01(\x08:3\n\x08populate\x12\x1f.google.protobuf.MessageOptions\x18\x87\xf4\x03 \x01(\x08:3\n\x08stringer\x12\x1f.google.protobuf.MessageOptions\x18\xc0\x8b\x04 \x01(\x08:2\n\x07onlyone\x12\x1f.google.protobuf.MessageOptions\x18\x89\xf4\x03 \x01(\x08:0\n\x05\x65qual\x12\x1f.google.protobuf.MessageOptions\x18\x8d\xf4\x03 \x01(\x08:6\n\x0b\x64\x65scription\x12\x1f.google.protobuf.MessageOptions\x18\x8e\xf4\x03 \x01(\x08:2\n\x07testgen\x12\x1f.google.protobuf.MessageOptions\x18\x8f\xf4\x03 \x01(\x08:3\n\x08\x62\x65nchgen\x12\x1f.google.protobuf.MessageOptions\x18\x90\xf4\x03 \x01(\x08:4\n\tmarshaler\x12\x1f.google.protobuf.MessageOptions\x18\x91\xf4\x03 \x01(\x08:6\n\x0bunmarshaler\x12\x1f.google.protobuf.MessageOptions\x18\x92\xf4\x03 \x01(\x08:;\n\x10stable_marshaler\x12\x1f.google.protobuf.MessageOptions\x18\x93\xf4\x03 \x01(\x08:0\n\x05sizer\x12\x1f.google.protobuf.MessageOptions\x18\x94\xf4\x03 \x01(\x08:;\n\x10unsafe_marshaler\x12\x1f.google.protobuf.MessageOptions\x18\x97\xf4\x03 \x01(\x08:=\n\x12unsafe_unmarshaler\x12\x1f.google.protobuf.MessageOptions\x18\x98\xf4\x03 \x01(\x08:A\n\x16goproto_extensions_map\x12\x1f.google.protobuf.MessageOptions\x18\x99\xf4\x03 \x01(\x08:?\n\x14goproto_unrecognized\x12\x1f.google.protobuf.MessageOptions\x18\x9a\xf4\x03 \x01(\x08:5\n\nprotosizer\x12\x1f.google.protobuf.MessageOptions\x18\x9c\xf4\x03 \x01(\x08:2\n\x07\x63ompare\x12\x1f.google.protobuf.MessageOptions\x18\x9d\xf4\x03 \x01(\x08:3\n\x08typedecl\x12\x1f.google.protobuf.MessageOptions\x18\x9e\xf4\x03 \x01(\x08:6\n\x0bmessagename\x12\x1f.google.protobuf.MessageOptions\x18\xa1\xf4\x03 \x01(\x08:<\n\x11goproto_sizecache\x12\x1f.google.protobuf.MessageOptions\x18\xa2\xf4\x03 \x01(\x08::\n\x0fgoproto_unkeyed\x12\x1f.google.protobuf.MessageOptions\x18\xa3\xf4\x03 \x01(\x08:1\n\x08nullable\x12\x1d.google.protobuf.FieldOptions\x18\xe9\xfb\x03 \x01(\x08:.\n\x05\x65mbed\x12\x1d.google.protobuf.FieldOptions\x18\xea\xfb\x03 \x01(\x08:3\n\ncustomtype\x12\x1d.google.protobuf.FieldOptions\x18\xeb\xfb\x03 \x01(\t:3\n\ncustomname\x12\x1d.google.protobuf.FieldOptions\x18\xec\xfb\x03 \x01(\t:0\n\x07jsontag\x12\x1d.google.protobuf.FieldOptions\x18\xed\xfb\x03 \x01(\t:1\n\x08moretags\x12\x1d.google.protobuf.FieldOptions\x18\xee\xfb\x03 \x01(\t:1\n\x08\x63\x61sttype\x12\x1d.google.protobuf.FieldOptions\x18\xef\xfb\x03 \x01(\t:0\n\x07\x63\x61stkey\x12\x1d.google.protobuf.FieldOptions\x18\xf0\xfb\x03 \x01(\t:2\n\tcastvalue\x12\x1d.google.protobuf.FieldOptions\x18\xf1\xfb\x03 \x01(\t:0\n\x07stdtime\x12\x1d.google.protobuf.FieldOptions\x18\xf2\xfb\x03 \x01(\x08:4\n\x0bstdduration\x12\x1d.google.protobuf.FieldOptions\x18\xf3\xfb\x03 \x01(\x08:3\n\nwktpointer\x12\x1d.google.protobuf.FieldOptions\x18\xf4\xfb\x03 \x01(\x08:5\n\x0c\x63\x61strepeated\x12\x1d.google.protobuf.FieldOptions\x18\xf5\xfb\x03 \x01(\tBE\n\x13\x63om.google.protobufB\nGoGoProtosZ\"github.com/gogo/protobuf/gogoproto'
  ,
  dependencies=[google_dot_protobuf_dot_descriptor__pb2.DESCRIPTOR,])


GOPROTO_ENUM_PREFIX_FIELD_NUMBER = 62001
goproto_enum_prefix = _descriptor.FieldDescriptor(
  name='goproto_enum_prefix', full_name='gogoproto.goproto_enum_prefix', index=0,
  number=62001, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_ENUM_STRINGER_FIELD_NUMBER = 62021
goproto_enum_stringer = _descriptor.FieldDescriptor(
  name='goproto_enum_stringer', full_name='gogoproto.goproto_enum_stringer', index=1,
  number=62021, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ENUM_STRINGER_FIELD_NUMBER = 62022
enum_stringer = _descriptor.FieldDescriptor(
  name='enum_stringer', full_name='gogoproto.enum_stringer', index=2,
  number=62022, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ENUM_CUSTOMNAME_FIELD_NUMBER = 62023
enum_customname = _descriptor.FieldDescriptor(
  name='enum_customname', full_name='gogoproto.enum_customname', index=3,
  number=62023, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ENUMDECL_FIELD_NUMBER = 62024
enumdecl = _descriptor.FieldDescriptor(
  name='enumdecl', full_name='gogoproto.enumdecl', index=4,
  number=62024, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ENUMVALUE_CUSTOMNAME_FIELD_NUMBER = 66001
enumvalue_customname = _descriptor.FieldDescriptor(
  name='enumvalue_customname', full_name='gogoproto.enumvalue_customname', index=5,
  number=66001, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_GETTERS_ALL_FIELD_NUMBER = 63001
goproto_getters_all = _descriptor.FieldDescriptor(
  name='goproto_getters_all', full_name='gogoproto.goproto_getters_all', index=6,
  number=63001, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_ENUM_PREFIX_ALL_FIELD_NUMBER = 63002
goproto_enum_prefix_all = _descriptor.FieldDescriptor(
  name='goproto_enum_prefix_all', full_name='gogoproto.goproto_enum_prefix_all', index=7,
  number=63002, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_STRINGER_ALL_FIELD_NUMBER = 63003
goproto_stringer_all = _descriptor.FieldDescriptor(
  name='goproto_stringer_all', full_name='gogoproto.goproto_stringer_all', index=8,
  number=63003, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
VERBOSE_EQUAL_ALL_FIELD_NUMBER = 63004
verbose_equal_all = _descriptor.FieldDescriptor(
  name='verbose_equal_all', full_name='gogoproto.verbose_equal_all', index=9,
  number=63004, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
FACE_ALL_FIELD_NUMBER = 63005
face_all = _descriptor.FieldDescriptor(
  name='face_all', full_name='gogoproto.face_all', index=10,
  number=63005, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOSTRING_ALL_FIELD_NUMBER = 63006
gostring_all = _descriptor.FieldDescriptor(
  name='gostring_all', full_name='gogoproto.gostring_all', index=11,
  number=63006, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
POPULATE_ALL_FIELD_NUMBER = 63007
populate_all = _descriptor.FieldDescriptor(
  name='populate_all', full_name='gogoproto.populate_all', index=12,
  number=63007, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
STRINGER_ALL_FIELD_NUMBER = 63008
stringer_all = _descriptor.FieldDescriptor(
  name='stringer_all', full_name='gogoproto.stringer_all', index=13,
  number=63008, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ONLYONE_ALL_FIELD_NUMBER = 63009
onlyone_all = _descriptor.FieldDescriptor(
  name='onlyone_all', full_name='gogoproto.onlyone_all', index=14,
  number=63009, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
EQUAL_ALL_FIELD_NUMBER = 63013
equal_all = _descriptor.FieldDescriptor(
  name='equal_all', full_name='gogoproto.equal_all', index=15,
  number=63013, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DESCRIPTION_ALL_FIELD_NUMBER = 63014
description_all = _descriptor.FieldDescriptor(
  name='description_all', full_name='gogoproto.description_all', index=16,
  number=63014, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
TESTGEN_ALL_FIELD_NUMBER = 63015
testgen_all = _descriptor.FieldDescriptor(
  name='testgen_all', full_name='gogoproto.testgen_all', index=17,
  number=63015, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
BENCHGEN_ALL_FIELD_NUMBER = 63016
benchgen_all = _descriptor.FieldDescriptor(
  name='benchgen_all', full_name='gogoproto.benchgen_all', index=18,
  number=63016, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
MARSHALER_ALL_FIELD_NUMBER = 63017
marshaler_all = _descriptor.FieldDescriptor(
  name='marshaler_all', full_name='gogoproto.marshaler_all', index=19,
  number=63017, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNMARSHALER_ALL_FIELD_NUMBER = 63018
unmarshaler_all = _descriptor.FieldDescriptor(
  name='unmarshaler_all', full_name='gogoproto.unmarshaler_all', index=20,
  number=63018, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
STABLE_MARSHALER_ALL_FIELD_NUMBER = 63019
stable_marshaler_all = _descriptor.FieldDescriptor(
  name='stable_marshaler_all', full_name='gogoproto.stable_marshaler_all', index=21,
  number=63019, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
SIZER_ALL_FIELD_NUMBER = 63020
sizer_all = _descriptor.FieldDescriptor(
  name='sizer_all', full_name='gogoproto.sizer_all', index=22,
  number=63020, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_ENUM_STRINGER_ALL_FIELD_NUMBER = 63021
goproto_enum_stringer_all = _descriptor.FieldDescriptor(
  name='goproto_enum_stringer_all', full_name='gogoproto.goproto_enum_stringer_all', index=23,
  number=63021, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ENUM_STRINGER_ALL_FIELD_NUMBER = 63022
enum_stringer_all = _descriptor.FieldDescriptor(
  name='enum_stringer_all', full_name='gogoproto.enum_stringer_all', index=24,
  number=63022, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNSAFE_MARSHALER_ALL_FIELD_NUMBER = 63023
unsafe_marshaler_all = _descriptor.FieldDescriptor(
  name='unsafe_marshaler_all', full_name='gogoproto.unsafe_marshaler_all', index=25,
  number=63023, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNSAFE_UNMARSHALER_ALL_FIELD_NUMBER = 63024
unsafe_unmarshaler_all = _descriptor.FieldDescriptor(
  name='unsafe_unmarshaler_all', full_name='gogoproto.unsafe_unmarshaler_all', index=26,
  number=63024, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_EXTENSIONS_MAP_ALL_FIELD_NUMBER = 63025
goproto_extensions_map_all = _descriptor.FieldDescriptor(
  name='goproto_extensions_map_all', full_name='gogoproto.goproto_extensions_map_all', index=27,
  number=63025, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_UNRECOGNIZED_ALL_FIELD_NUMBER = 63026
goproto_unrecognized_all = _descriptor.FieldDescriptor(
  name='goproto_unrecognized_all', full_name='gogoproto.goproto_unrecognized_all', index=28,
  number=63026, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOGOPROTO_IMPORT_FIELD_NUMBER = 63027
gogoproto_import = _descriptor.FieldDescriptor(
  name='gogoproto_import', full_name='gogoproto.gogoproto_import', index=29,
  number=63027, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PROTOSIZER_ALL_FIELD_NUMBER = 63028
protosizer_all = _descriptor.FieldDescriptor(
  name='protosizer_all', full_name='gogoproto.protosizer_all', index=30,
  number=63028, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
COMPARE_ALL_FIELD_NUMBER = 63029
compare_all = _descriptor.FieldDescriptor(
  name='compare_all', full_name='gogoproto.compare_all', index=31,
  number=63029, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
TYPEDECL_ALL_FIELD_NUMBER = 63030
typedecl_all = _descriptor.FieldDescriptor(
  name='typedecl_all', full_name='gogoproto.typedecl_all', index=32,
  number=63030, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ENUMDECL_ALL_FIELD_NUMBER = 63031
enumdecl_all = _descriptor.FieldDescriptor(
  name='enumdecl_all', full_name='gogoproto.enumdecl_all', index=33,
  number=63031, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_REGISTRATION_FIELD_NUMBER = 63032
goproto_registration = _descriptor.FieldDescriptor(
  name='goproto_registration', full_name='gogoproto.goproto_registration', index=34,
  number=63032, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
MESSAGENAME_ALL_FIELD_NUMBER = 63033
messagename_all = _descriptor.FieldDescriptor(
  name='messagename_all', full_name='gogoproto.messagename_all', index=35,
  number=63033, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_SIZECACHE_ALL_FIELD_NUMBER = 63034
goproto_sizecache_all = _descriptor.FieldDescriptor(
  name='goproto_sizecache_all', full_name='gogoproto.goproto_sizecache_all', index=36,
  number=63034, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_UNKEYED_ALL_FIELD_NUMBER = 63035
goproto_unkeyed_all = _descriptor.FieldDescriptor(
  name='goproto_unkeyed_all', full_name='gogoproto.goproto_unkeyed_all', index=37,
  number=63035, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_GETTERS_FIELD_NUMBER = 64001
goproto_getters = _descriptor.FieldDescriptor(
  name='goproto_getters', full_name='gogoproto.goproto_getters', index=38,
  number=64001, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_STRINGER_FIELD_NUMBER = 64003
goproto_stringer = _descriptor.FieldDescriptor(
  name='goproto_stringer', full_name='gogoproto.goproto_stringer', index=39,
  number=64003, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
VERBOSE_EQUAL_FIELD_NUMBER = 64004
verbose_equal = _descriptor.FieldDescriptor(
  name='verbose_equal', full_name='gogoproto.verbose_equal', index=40,
  number=64004, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
FACE_FIELD_NUMBER = 64005
face = _descriptor.FieldDescriptor(
  name='face', full_name='gogoproto.face', index=41,
  number=64005, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOSTRING_FIELD_NUMBER = 64006
gostring = _descriptor.FieldDescriptor(
  name='gostring', full_name='gogoproto.gostring', index=42,
  number=64006, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
POPULATE_FIELD_NUMBER = 64007
populate = _descriptor.FieldDescriptor(
  name='populate', full_name='gogoproto.populate', index=43,
  number=64007, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
STRINGER_FIELD_NUMBER = 67008
stringer = _descriptor.FieldDescriptor(
  name='stringer', full_name='gogoproto.stringer', index=44,
  number=67008, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
ONLYONE_FIELD_NUMBER = 64009
onlyone = _descriptor.FieldDescriptor(
  name='onlyone', full_name='gogoproto.onlyone', index=45,
  number=64009, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
EQUAL_FIELD_NUMBER = 64013
equal = _descriptor.FieldDescriptor(
  name='equal', full_name='gogoproto.equal', index=46,
  number=64013, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
DESCRIPTION_FIELD_NUMBER = 64014
description = _descriptor.FieldDescriptor(
  name='description', full_name='gogoproto.description', index=47,
  number=64014, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
TESTGEN_FIELD_NUMBER = 64015
testgen = _descriptor.FieldDescriptor(
  name='testgen', full_name='gogoproto.testgen', index=48,
  number=64015, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
BENCHGEN_FIELD_NUMBER = 64016
benchgen = _descriptor.FieldDescriptor(
  name='benchgen', full_name='gogoproto.benchgen', index=49,
  number=64016, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
MARSHALER_FIELD_NUMBER = 64017
marshaler = _descriptor.FieldDescriptor(
  name='marshaler', full_name='gogoproto.marshaler', index=50,
  number=64017, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNMARSHALER_FIELD_NUMBER = 64018
unmarshaler = _descriptor.FieldDescriptor(
  name='unmarshaler', full_name='gogoproto.unmarshaler', index=51,
  number=64018, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
STABLE_MARSHALER_FIELD_NUMBER = 64019
stable_marshaler = _descriptor.FieldDescriptor(
  name='stable_marshaler', full_name='gogoproto.stable_marshaler', index=52,
  number=64019, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
SIZER_FIELD_NUMBER = 64020
sizer = _descriptor.FieldDescriptor(
  name='sizer', full_name='gogoproto.sizer', index=53,
  number=64020, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNSAFE_MARSHALER_FIELD_NUMBER = 64023
unsafe_marshaler = _descriptor.FieldDescriptor(
  name='unsafe_marshaler', full_name='gogoproto.unsafe_marshaler', index=54,
  number=64023, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
UNSAFE_UNMARSHALER_FIELD_NUMBER = 64024
unsafe_unmarshaler = _descriptor.FieldDescriptor(
  name='unsafe_unmarshaler', full_name='gogoproto.unsafe_unmarshaler', index=55,
  number=64024, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_EXTENSIONS_MAP_FIELD_NUMBER = 64025
goproto_extensions_map = _descriptor.FieldDescriptor(
  name='goproto_extensions_map', full_name='gogoproto.goproto_extensions_map', index=56,
  number=64025, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_UNRECOGNIZED_FIELD_NUMBER = 64026
goproto_unrecognized = _descriptor.FieldDescriptor(
  name='goproto_unrecognized', full_name='gogoproto.goproto_unrecognized', index=57,
  number=64026, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
PROTOSIZER_FIELD_NUMBER = 64028
protosizer = _descriptor.FieldDescriptor(
  name='protosizer', full_name='gogoproto.protosizer', index=58,
  number=64028, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
COMPARE_FIELD_NUMBER = 64029
compare = _descriptor.FieldDescriptor(
  name='compare', full_name='gogoproto.compare', index=59,
  number=64029, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
TYPEDECL_FIELD_NUMBER = 64030
typedecl = _descriptor.FieldDescriptor(
  name='typedecl', full_name='gogoproto.typedecl', index=60,
  number=64030, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
MESSAGENAME_FIELD_NUMBER = 64033
messagename = _descriptor.FieldDescriptor(
  name='messagename', full_name='gogoproto.messagename', index=61,
  number=64033, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_SIZECACHE_FIELD_NUMBER = 64034
goproto_sizecache = _descriptor.FieldDescriptor(
  name='goproto_sizecache', full_name='gogoproto.goproto_sizecache', index=62,
  number=64034, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
GOPROTO_UNKEYED_FIELD_NUMBER = 64035
goproto_unkeyed = _descriptor.FieldDescriptor(
  name='goproto_unkeyed', full_name='gogoproto.goproto_unkeyed', index=63,
  number=64035, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
NULLABLE_FIELD_NUMBER = 65001
nullable = _descriptor.FieldDescriptor(
  name='nullable', full_name='gogoproto.nullable', index=64,
  number=65001, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
EMBED_FIELD_NUMBER = 65002
embed = _descriptor.FieldDescriptor(
  name='embed', full_name='gogoproto.embed', index=65,
  number=65002, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
CUSTOMTYPE_FIELD_NUMBER = 65003
customtype = _descriptor.FieldDescriptor(
  name='customtype', full_name='gogoproto.customtype', index=66,
  number=65003, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
CUSTOMNAME_FIELD_NUMBER = 65004
customname = _descriptor.FieldDescriptor(
  name='customname', full_name='gogoproto.customname', index=67,
  number=65004, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
JSONTAG_FIELD_NUMBER = 65005
jsontag = _descriptor.FieldDescriptor(
  name='jsontag', full_name='gogoproto.jsontag', index=68,
  number=65005, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
MORETAGS_FIELD_NUMBER = 65006
moretags = _descriptor.FieldDescriptor(
  name='moretags', full_name='gogoproto.moretags', index=69,
  number=65006, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
CASTTYPE_FIELD_NUMBER = 65007
casttype = _descriptor.FieldDescriptor(
  name='casttype', full_name='gogoproto.casttype', index=70,
  number=65007, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
CASTKEY_FIELD_NUMBER = 65008
castkey = _descriptor.FieldDescriptor(
  name='castkey', full_name='gogoproto.castkey', index=71,
  number=65008, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
CASTVALUE_FIELD_NUMBER = 65009
castvalue = _descriptor.FieldDescriptor(
  name='castvalue', full_name='gogoproto.castvalue', index=72,
  number=65009, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
STDTIME_FIELD_NUMBER = 65010
stdtime = _descriptor.FieldDescriptor(
  name='stdtime', full_name='gogoproto.stdtime', index=73,
  number=65010, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
STDDURATION_FIELD_NUMBER = 65011
stdduration = _descriptor.FieldDescriptor(
  name='stdduration', full_name='gogoproto.stdduration', index=74,
  number=65011, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
WKTPOINTER_FIELD_NUMBER = 65012
wktpointer = _descriptor.FieldDescriptor(
  name='wktpointer', full_name='gogoproto.wktpointer', index=75,
  number=65012, type=8, cpp_type=7, label=1,
  has_default_value=False, default_value=False,
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)
CASTREPEATED_FIELD_NUMBER = 65013
castrepeated = _descriptor.FieldDescriptor(
  name='castrepeated', full_name='gogoproto.castrepeated', index=76,
  number=65013, type=9, cpp_type=9, label=1,
  has_default_value=False, default_value=b"".decode('utf-8'),
  message_type=None, enum_type=None, containing_type=None,
  is_extension=True, extension_scope=None,
  serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key)

DESCRIPTOR.extensions_by_name['goproto_enum_prefix'] = goproto_enum_prefix
DESCRIPTOR.extensions_by_name['goproto_enum_stringer'] = goproto_enum_stringer
DESCRIPTOR.extensions_by_name['enum_stringer'] = enum_stringer
DESCRIPTOR.extensions_by_name['enum_customname'] = enum_customname
DESCRIPTOR.extensions_by_name['enumdecl'] = enumdecl
DESCRIPTOR.extensions_by_name['enumvalue_customname'] = enumvalue_customname
DESCRIPTOR.extensions_by_name['goproto_getters_all'] = goproto_getters_all
DESCRIPTOR.extensions_by_name['goproto_enum_prefix_all'] = goproto_enum_prefix_all
DESCRIPTOR.extensions_by_name['goproto_stringer_all'] = goproto_stringer_all
DESCRIPTOR.extensions_by_name['verbose_equal_all'] = verbose_equal_all
DESCRIPTOR.extensions_by_name['face_all'] = face_all
DESCRIPTOR.extensions_by_name['gostring_all'] = gostring_all
DESCRIPTOR.extensions_by_name['populate_all'] = populate_all
DESCRIPTOR.extensions_by_name['stringer_all'] = stringer_all
DESCRIPTOR.extensions_by_name['onlyone_all'] = onlyone_all
DESCRIPTOR.extensions_by_name['equal_all'] = equal_all
DESCRIPTOR.extensions_by_name['description_all'] = description_all
DESCRIPTOR.extensions_by_name['testgen_all'] = testgen_all
DESCRIPTOR.extensions_by_name['benchgen_all'] = benchgen_all
DESCRIPTOR.extensions_by_name['marshaler_all'] = marshaler_all
DESCRIPTOR.extensions_by_name['unmarshaler_all'] = unmarshaler_all
DESCRIPTOR.extensions_by_name['stable_marshaler_all'] = stable_marshaler_all
DESCRIPTOR.extensions_by_name['sizer_all'] = sizer_all
DESCRIPTOR.extensions_by_name['goproto_enum_stringer_all'] = goproto_enum_stringer_all
DESCRIPTOR.extensions_by_name['enum_stringer_all'] = enum_stringer_all
DESCRIPTOR.extensions_by_name['unsafe_marshaler_all'] = unsafe_marshaler_all
DESCRIPTOR.extensions_by_name['unsafe_unmarshaler_all'] = unsafe_unmarshaler_all
DESCRIPTOR.extensions_by_name['goproto_extensions_map_all'] = goproto_extensions_map_all
DESCRIPTOR.extensions_by_name['goproto_unrecognized_all'] = goproto_unrecognized_all
DESCRIPTOR.extensions_by_name['gogoproto_import'] = gogoproto_import
DESCRIPTOR.extensions_by_name['protosizer_all'] = protosizer_all
DESCRIPTOR.extensions_by_name['compare_all'] = compare_all
DESCRIPTOR.extensions_by_name['typedecl_all'] = typedecl_all
DESCRIPTOR.extensions_by_name['enumdecl_all'] = enumdecl_all
DESCRIPTOR.extensions_by_name['goproto_registration'] = goproto_registration
DESCRIPTOR.extensions_by_name['messagename_all'] = messagename_all
DESCRIPTOR.extensions_by_name['goproto_sizecache_all'] = goproto_sizecache_all
DESCRIPTOR.extensions_by_name['goproto_unkeyed_all'] = goproto_unkeyed_all
DESCRIPTOR.extensions_by_name['goproto_getters'] = goproto_getters
DESCRIPTOR.extensions_by_name['goproto_stringer'] = goproto_stringer
DESCRIPTOR.extensions_by_name['verbose_equal'] = verbose_equal
DESCRIPTOR.extensions_by_name['face'] = face
DESCRIPTOR.extensions_by_name['gostring'] = gostring
DESCRIPTOR.extensions_by_name['populate'] = populate
DESCRIPTOR.extensions_by_name['stringer'] = stringer
DESCRIPTOR.extensions_by_name['onlyone'] = onlyone
DESCRIPTOR.extensions_by_name['equal'] = equal
DESCRIPTOR.extensions_by_name['description'] = description
DESCRIPTOR.extensions_by_name['testgen'] = testgen
DESCRIPTOR.extensions_by_name['benchgen'] = benchgen
DESCRIPTOR.extensions_by_name['marshaler'] = marshaler
DESCRIPTOR.extensions_by_name['unmarshaler'] = unmarshaler
DESCRIPTOR.extensions_by_name['stable_marshaler'] = stable_marshaler
DESCRIPTOR.extensions_by_name['sizer'] = sizer
DESCRIPTOR.extensions_by_name['unsafe_marshaler'] = unsafe_marshaler
DESCRIPTOR.extensions_by_name['unsafe_unmarshaler'] = unsafe_unmarshaler
DESCRIPTOR.extensions_by_name['goproto_extensions_map'] = goproto_extensions_map
DESCRIPTOR.extensions_by_name['goproto_unrecognized'] = goproto_unrecognized
DESCRIPTOR.extensions_by_name['protosizer'] = protosizer
DESCRIPTOR.extensions_by_name['compare'] = compare
DESCRIPTOR.extensions_by_name['typedecl'] = typedecl
DESCRIPTOR.extensions_by_name['messagename'] = messagename
DESCRIPTOR.extensions_by_name['goproto_sizecache'] = goproto_sizecache
DESCRIPTOR.extensions_by_name['goproto_unkeyed'] = goproto_unkeyed
DESCRIPTOR.extensions_by_name['nullable'] = nullable
DESCRIPTOR.extensions_by_name['embed'] = embed
DESCRIPTOR.extensions_by_name['customtype'] = customtype
DESCRIPTOR.extensions_by_name['customname'] = customname
DESCRIPTOR.extensions_by_name['jsontag'] = jsontag
DESCRIPTOR.extensions_by_name['moretags'] = moretags
DESCRIPTOR.extensions_by_name['casttype'] = casttype
DESCRIPTOR.extensions_by_name['castkey'] = castkey
DESCRIPTOR.extensions_by_name['castvalue'] = castvalue
DESCRIPTOR.extensions_by_name['stdtime'] = stdtime
DESCRIPTOR.extensions_by_name['stdduration'] = stdduration
DESCRIPTOR.extensions_by_name['wktpointer'] = wktpointer
DESCRIPTOR.extensions_by_name['castrepeated'] = castrepeated
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(goproto_enum_prefix)
google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(goproto_enum_stringer)
google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(enum_stringer)
google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(enum_customname)
google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(enumdecl)
google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(enumvalue_customname)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(goproto_getters_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(goproto_enum_prefix_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(goproto_stringer_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(verbose_equal_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(face_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(gostring_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(populate_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(stringer_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(onlyone_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(equal_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(description_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(testgen_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(benchgen_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(marshaler_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(unmarshaler_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(stable_marshaler_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(sizer_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(goproto_enum_stringer_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(enum_stringer_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(unsafe_marshaler_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(unsafe_unmarshaler_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(goproto_extensions_map_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(goproto_unrecognized_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(gogoproto_import)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(protosizer_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(compare_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(typedecl_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(enumdecl_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(goproto_registration)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(messagename_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(goproto_sizecache_all)
google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(goproto_unkeyed_all)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(goproto_getters)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(goproto_stringer)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(verbose_equal)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(face)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(gostring)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(populate)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(stringer)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(onlyone)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(equal)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(description)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(testgen)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(benchgen)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(marshaler)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(unmarshaler)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(stable_marshaler)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(sizer)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(unsafe_marshaler)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(unsafe_unmarshaler)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(goproto_extensions_map)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(goproto_unrecognized)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(protosizer)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(compare)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(typedecl)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(messagename)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(goproto_sizecache)
google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(goproto_unkeyed)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(nullable)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(embed)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(customtype)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(customname)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(jsontag)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(moretags)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(casttype)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(castkey)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(castvalue)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(stdtime)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(stdduration)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(wktpointer)
google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(castrepeated)

DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: msg_send.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import osmopy.interfaces.gogo_pb2 as gogo__pb2
import osmopy.interfaces.coin_pb2 as coin__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='msg_send.proto',
  package='cosmos.bank.v1beta1',
  syntax='proto3',
  serialized_options=b'Z)github.com/cosmos/cosmos-sdk/x/bank/types',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x0emsg_send.proto\x12\x13\x63osmos.bank.v1beta1\x1a\ngogo.proto\x1a\ncoin.proto\"\xca\x01\n\x07MsgSend\x12-\n\x0c\x66rom_address\x18\x01 \x01(\tB\x17\xf2\xde\x1f\x13yaml:\"from_address\"\x12)\n\nto_address\x18\x02 \x01(\tB\x15\xf2\xde\x1f\x11yaml:\"to_address\"\x12[\n\x06\x61mount\x18\x03 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins:\x08\xe8\xa0\x1f\x00\x88\xa0\x1f\x00\x42+Z)github.com/cosmos/cosmos-sdk/x/bank/typesb\x06proto3'
  ,
  dependencies=[gogo__pb2.DESCRIPTOR,coin__pb2.DESCRIPTOR,])




_MSGSEND = _descriptor.Descriptor(
  name='MsgSend',
  full_name='cosmos.bank.v1beta1.MsgSend',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='from_address', full_name='cosmos.bank.v1beta1.MsgSend.from_address', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\023yaml:\"from_address\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_address', full_name='cosmos.bank.v1beta1.MsgSend.to_address', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\362\336\037\021yaml:\"to_address\"', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='cosmos.bank.v1beta1.MsgSend.amount', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\000\210\240\037\000',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=266,
)

_MSGSEND.fields_by_name['amount'].message_type = coin__pb2._COIN
DESCRIPTOR.message_types_by_name['MsgSend'] = _MSGSEND
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MsgSend = _reflection.GeneratedProtocolMessageType('MsgSend', (_message.Message,), {
  'DESCRIPTOR' : _MSGSEND,
  '__module__' : 'msg_send_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.bank.v1beta1.MsgSend)
  })
_sym_db.RegisterMessage(MsgSend)


DESCRIPTOR._options = None
_MSGSEND.fields_by_name['from_address']._options = None
_MSGSEND.fields_by_name['to_address']._options = None
_MSGSEND.fields_by_name['amount']._options = None
_MSGSEND._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: coin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import osmopy.interfaces.gogo_pb2 as gogo__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='coin.proto',
  package='cosmos.base.v1beta1',
  syntax='proto3',
  serialized_options=b'Z\"github.com/cosmos/cosmos-sdk/types\330\341\036\000\200\342\036\000',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\ncoin.proto\x12\x13\x63osmos.base.v1beta1\x1a\ngogo.proto\"8\n\x04\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x1b\n\x06\x61mount\x18\x02 \x01(\tB\x0b\xda\xde\x1f\x03Int\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\";\n\x07\x44\x65\x63\x43oin\x12\r\n\x05\x64\x65nom\x18\x01 \x01(\t\x12\x1b\n\x06\x61mount\x18\x02 \x01(\tB\x0b\xda\xde\x1f\x03\x44\x65\x63\xc8\xde\x1f\x00:\x04\xe8\xa0\x1f\x01\"$\n\x08IntProto\x12\x18\n\x03int\x18\x01 \x01(\tB\x0b\xda\xde\x1f\x03Int\xc8\xde\x1f\x00\"$\n\x08\x44\x65\x63Proto\x12\x18\n\x03\x64\x65\x63\x18\x01 \x01(\tB\x0b\xda\xde\x1f\x03\x44\x65\x63\xc8\xde\x1f\x00\x42,Z\"github.com/cosmos/cosmos-sdk/types\xd8\xe1\x1e\x00\x80\xe2\x1e\x00\x62\x06proto3'
  ,
  dependencies=[gogo__pb2.DESCRIPTOR,])




_COIN = _descriptor.Descriptor(
  name='Coin',
  full_name='cosmos.base.v1beta1.Coin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='denom', full_name='cosmos.base.v1beta1.Coin.denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='cosmos.base.v1beta1.Coin.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037\003Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=47,
  serialized_end=103,
)


_DECCOIN = _descriptor.Descriptor(
  name='DecCoin',
  full_name='cosmos.base.v1beta1.DecCoin',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='denom', full_name='cosmos.base.v1beta1.DecCoin.denom', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='amount', full_name='cosmos.base.v1beta1.DecCoin.amount', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037\003Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'\350\240\037\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=105,
  serialized_end=164,
)


_INTPROTO = _descriptor.Descriptor(
  name='IntProto',
  full_name='cosmos.base.v1beta1.IntProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='int', full_name='cosmos.base.v1beta1.IntProto.int', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037\003Int\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=166,
  serialized_end=202,
)


_DECPROTO = _descriptor.Descriptor(
  name='DecProto',
  full_name='cosmos.base.v1beta1.DecProto',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='dec', full_name='cosmos.base.v1beta1.DecProto.dec', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\332\336\037\003Dec\310\336\037\000', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=204,
  serialized_end=240,
)

DESCRIPTOR.message_types_by_name['Coin'] = _COIN
DESCRIPTOR.message_types_by_name['DecCoin'] = _DECCOIN
DESCRIPTOR.message_types_by_name['IntProto'] = _INTPROTO
DESCRIPTOR.message_types_by_name['DecProto'] = _DECPROTO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Coin = _reflection.GeneratedProtocolMessageType('Coin', (_message.Message,), {
  'DESCRIPTOR' : _COIN,
  '__module__' : 'coin_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.v1beta1.Coin)
  })
_sym_db.RegisterMessage(Coin)

DecCoin = _reflection.GeneratedProtocolMessageType('DecCoin', (_message.Message,), {
  'DESCRIPTOR' : _DECCOIN,
  '__module__' : 'coin_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.v1beta1.DecCoin)
  })
_sym_db.RegisterMessage(DecCoin)

IntProto = _reflection.GeneratedProtocolMessageType('IntProto', (_message.Message,), {
  'DESCRIPTOR' : _INTPROTO,
  '__module__' : 'coin_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.v1beta1.IntProto)
  })
_sym_db.RegisterMessage(IntProto)

DecProto = _reflection.GeneratedProtocolMessageType('DecProto', (_message.Message,), {
  'DESCRIPTOR' : _DECPROTO,
  '__module__' : 'coin_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.base.v1beta1.DecProto)
  })
_sym_db.RegisterMessage(DecProto)


DESCRIPTOR._options = None
_COIN.fields_by_name['amount']._options = None
_COIN._options = None
_DECCOIN.fields_by_name['amount']._options = None
_DECCOIN._options = None
_INTPROTO.fields_by_name['int']._options = None
_DECPROTO.fields_by_name['dec']._options = None
# @@protoc_insertion_point(module_scope)



from setuptools import setup

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name='osmopy',
    version='0.0.2',
    packages=['osmopy', 'osmopy.interfaces'],
    url='https://github.com/bro-n-bro/osmopy',
    license='MIT',
    author='bro-n-bro-0',
    author_email='',
    description='Tools for Osmosis wallet management, offline transaction signing and broadcasting',
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=[
        'ecdsa',
        'bech32',
        'hdwallets',
        'mnemonic',
        'typing-extensions',
        'requests'
      ],
    zip_safe=False,
)



import base64
import hashlib
import json
import requests
import ecdsa

import osmopy.interfaces.tx_pb2 as tx
import osmopy.interfaces.msg_send_pb2 as transfer
import osmopy.interfaces.coin_pb2 as coin
import osmopy.interfaces.pubkey_pb2 as pubkey

from osmopy.interfaces.any_pb2 import Any
from osmopy._wallet import privkey_to_address, privkey_to_pubkey
from osmopy._typing import SyncMode


class Transaction:
    """A osmosis transaction.

    After initialization, one or more messages can be added by
    calling the `add_transfer()` method. Then, call `get_pushable()`
    to get a signed transaction that can be pushed to the `POST /txs`
    endpoint of the osmosis RPC or call `broadcast(url=<RPC_api>)` method
    to get signed transaction and broadcast it with RPC_API.
    """

    def __init__(
        self,
        *,
        privkey: bytes,
        account_num: int,
        sequence: int,
        fee: int,
        gas: int,
        fee_denom: str = "uosmo",
        memo: str = "",
        chain_id: str = "osmosis-1",
        sync_mode: SyncMode = "broadcast_tx_commit",
    ) -> None:
        self._raw_tx = tx.TxRaw()
        self._tx_body = tx.TxBody()
        self._tx_body.memo = memo
        self._privkey = privkey
        self._account_num = account_num
        self._sequence = sequence
        self._fee = fee
        self._fee_denom = fee_denom
        self._gas = gas
        self._chain_id = chain_id
        self._sync_mode = sync_mode

    def add_transfer(self, recipient: str, amount: int, denom: str = "uosmo") -> None:
        msg_send = transfer.MsgSend()
        msg_send.from_address = privkey_to_address(self._privkey)
        msg_send.to_address = recipient
        _amount = coin.Coin()
        _amount.denom = denom
        _amount.amount = str(amount)
        msg_send.amount.append(_amount)
        msg_send_any = Any()
        msg_send_any.Pack(msg_send)
        msg_send_any.type_url = '/cosmos.bank.v1beta1.MsgSend'
        self._tx_body.messages.append(msg_send_any)

    def get_pushable(self):
        self._raw_tx.body_bytes = self._tx_body.SerializeToString()
        self._raw_tx.auth_info_bytes = self._get_auth_info().SerializeToString()
        self._raw_tx.signatures.append(self._get_signatures())
        raw_tx = self._raw_tx.SerializeToString()
        tx_bytes = bytes(raw_tx)
        tx_b64 = base64.b64encode(tx_bytes).decode('utf-8')
        return json.dumps({
            "jsonrpc": "2.0",
            "id": 1,
            "method": self._sync_mode,
            "params": {
                "tx": tx_b64
                }
        })

    def _get_signatures(self):
        privkey = ecdsa.SigningKey.from_string(self._privkey, curve=ecdsa.SECP256k1)
        signature_compact = privkey.sign_deterministic(
            self._get_sign_doc().SerializeToString(), hashfunc=hashlib.sha256, sigencode=ecdsa.util.sigencode_string_canonize
        )
        return signature_compact

    def _get_sign_doc(self):
        sign_doc = tx.SignDoc()
        sign_doc.body_bytes = self._tx_body.SerializeToString()
        sign_doc.auth_info_bytes = self._get_auth_info().SerializeToString()
        sign_doc.chain_id = self._chain_id
        sign_doc.account_number = self._account_num
        return sign_doc

    def _get_auth_info(self):
        _auth_info = tx.AuthInfo()
        _auth_info.signer_infos.append(self._get_signer_infos(self._get_pubkey()))
        _auth_info.fee.gas_limit = self._gas
        _auth_info.fee.amount.append(self._get_fee())
        return _auth_info

    def _get_fee(self):
        _fee = coin.Coin()
        _fee.amount = str(self._fee)
        _fee.denom = self._fee_denom
        return _fee

    def _get_pubkey(self):
        pubkey_bytes = privkey_to_pubkey(self._privkey)
        _pubkey = pubkey.PubKey()
        _pubkey.key = pubkey_bytes
        return _pubkey

    def _get_signer_infos(self, _pubkey):
        signer_infos = tx.SignerInfo()
        signer_infos.sequence = self._sequence
        signer_infos.public_key.Pack(_pubkey)
        signer_infos.public_key.type_url = '/cosmos.crypto.secp256k1.PubKey'
        signer_infos.mode_info.single.mode = 1
        return signer_infos

    def broadcast(self, url):
        pushable_tx = self.get_pushable()
        res = requests.post(url=url, data=pushable_tx)
        if res.status_code == 200:
            res = res.json()
            return res
        else:
            raise Exception("Broadcact failed to run by returning code of {}".format(res.status_code))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tx.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import osmopy.interfaces.gogo_pb2 as gogo__pb2
import osmopy.interfaces.coin_pb2 as coin__pb2
import osmopy.interfaces.signing_pb2 as signing__pb2
import osmopy.interfaces.any_pb2 as any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='tx.proto',
  package='cosmos.tx.v1beta1',
  syntax='proto3',
  serialized_options=b'Z%github.com/cosmos/cosmos-sdk/types/tx',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x08tx.proto\x12\x11\x63osmos.tx.v1beta1\x1a\ngogo.proto\x1a\ncoin.proto\x1a\rsigning.proto\x1a\tany.proto\"q\n\x02Tx\x12\'\n\x04\x62ody\x18\x01 \x01(\x0b\x32\x19.cosmos.tx.v1beta1.TxBody\x12.\n\tauth_info\x18\x02 \x01(\x0b\x32\x1b.cosmos.tx.v1beta1.AuthInfo\x12\x12\n\nsignatures\x18\x03 \x03(\x0c\"H\n\x05TxRaw\x12\x12\n\nbody_bytes\x18\x01 \x01(\x0c\x12\x17\n\x0f\x61uth_info_bytes\x18\x02 \x01(\x0c\x12\x12\n\nsignatures\x18\x03 \x03(\x0c\"`\n\x07SignDoc\x12\x12\n\nbody_bytes\x18\x01 \x01(\x0c\x12\x17\n\x0f\x61uth_info_bytes\x18\x02 \x01(\x0c\x12\x10\n\x08\x63hain_id\x18\x03 \x01(\t\x12\x16\n\x0e\x61\x63\x63ount_number\x18\x04 \x01(\x04\"\xc7\x01\n\x06TxBody\x12&\n\x08messages\x18\x01 \x03(\x0b\x32\x14.google.protobuf.Any\x12\x0c\n\x04memo\x18\x02 \x01(\t\x12\x16\n\x0etimeout_height\x18\x03 \x01(\x04\x12\x30\n\x11\x65xtension_options\x18\xff\x07 \x03(\x0b\x32\x14.google.protobuf.Any\x12=\n\x1enon_critical_extension_options\x18\xff\x0f \x03(\x0b\x32\x14.google.protobuf.Any\"d\n\x08\x41uthInfo\x12\x33\n\x0csigner_infos\x18\x01 \x03(\x0b\x32\x1d.cosmos.tx.v1beta1.SignerInfo\x12#\n\x03\x66\x65\x65\x18\x02 \x01(\x0b\x32\x16.cosmos.tx.v1beta1.Fee\"x\n\nSignerInfo\x12(\n\npublic_key\x18\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x12.\n\tmode_info\x18\x02 \x01(\x0b\x32\x1b.cosmos.tx.v1beta1.ModeInfo\x12\x10\n\x08sequence\x18\x03 \x01(\x04\"\x84\x01\n\x08ModeInfo\x12\x34\n\x06single\x18\x01 \x01(\x0b\x32\".cosmos.tx.v1beta1.ModeInfo.SingleH\x00\x1a;\n\x06Single\x12\x31\n\x04mode\x18\x01 \x01(\x0e\x32#.cosmos.tx.signing.v1beta1.SignModeB\x05\n\x03sum\"\x95\x01\n\x03\x46\x65\x65\x12[\n\x06\x61mount\x18\x01 \x03(\x0b\x32\x19.cosmos.base.v1beta1.CoinB0\xc8\xde\x1f\x00\xaa\xdf\x1f(github.com/cosmos/cosmos-sdk/types.Coins\x12\x11\n\tgas_limit\x18\x02 \x01(\x04\x12\r\n\x05payer\x18\x03 \x01(\t\x12\x0f\n\x07granter\x18\x04 \x01(\tB\'Z%github.com/cosmos/cosmos-sdk/types/txb\x06proto3'
  ,
  dependencies=[gogo__pb2.DESCRIPTOR,coin__pb2.DESCRIPTOR,signing__pb2.DESCRIPTOR,any__pb2.DESCRIPTOR,])




_TX = _descriptor.Descriptor(
  name='Tx',
  full_name='cosmos.tx.v1beta1.Tx',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body', full_name='cosmos.tx.v1beta1.Tx.body', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_info', full_name='cosmos.tx.v1beta1.Tx.auth_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signatures', full_name='cosmos.tx.v1beta1.Tx.signatures', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=194,
)


_TXRAW = _descriptor.Descriptor(
  name='TxRaw',
  full_name='cosmos.tx.v1beta1.TxRaw',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body_bytes', full_name='cosmos.tx.v1beta1.TxRaw.body_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_info_bytes', full_name='cosmos.tx.v1beta1.TxRaw.auth_info_bytes', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signatures', full_name='cosmos.tx.v1beta1.TxRaw.signatures', index=2,
      number=3, type=12, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=196,
  serialized_end=268,
)


_SIGNDOC = _descriptor.Descriptor(
  name='SignDoc',
  full_name='cosmos.tx.v1beta1.SignDoc',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='body_bytes', full_name='cosmos.tx.v1beta1.SignDoc.body_bytes', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='auth_info_bytes', full_name='cosmos.tx.v1beta1.SignDoc.auth_info_bytes', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='chain_id', full_name='cosmos.tx.v1beta1.SignDoc.chain_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='account_number', full_name='cosmos.tx.v1beta1.SignDoc.account_number', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=270,
  serialized_end=366,
)


_TXBODY = _descriptor.Descriptor(
  name='TxBody',
  full_name='cosmos.tx.v1beta1.TxBody',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='cosmos.tx.v1beta1.TxBody.messages', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='memo', full_name='cosmos.tx.v1beta1.TxBody.memo', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout_height', full_name='cosmos.tx.v1beta1.TxBody.timeout_height', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extension_options', full_name='cosmos.tx.v1beta1.TxBody.extension_options', index=3,
      number=1023, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='non_critical_extension_options', full_name='cosmos.tx.v1beta1.TxBody.non_critical_extension_options', index=4,
      number=2047, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=369,
  serialized_end=568,
)


_AUTHINFO = _descriptor.Descriptor(
  name='AuthInfo',
  full_name='cosmos.tx.v1beta1.AuthInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='signer_infos', full_name='cosmos.tx.v1beta1.AuthInfo.signer_infos', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fee', full_name='cosmos.tx.v1beta1.AuthInfo.fee', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=670,
)


_SIGNERINFO = _descriptor.Descriptor(
  name='SignerInfo',
  full_name='cosmos.tx.v1beta1.SignerInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='public_key', full_name='cosmos.tx.v1beta1.SignerInfo.public_key', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mode_info', full_name='cosmos.tx.v1beta1.SignerInfo.mode_info', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='cosmos.tx.v1beta1.SignerInfo.sequence', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=672,
  serialized_end=792,
)


_MODEINFO_SINGLE = _descriptor.Descriptor(
  name='Single',
  full_name='cosmos.tx.v1beta1.ModeInfo.Single',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='cosmos.tx.v1beta1.ModeInfo.Single.mode', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=861,
  serialized_end=920,
)

_MODEINFO = _descriptor.Descriptor(
  name='ModeInfo',
  full_name='cosmos.tx.v1beta1.ModeInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='single', full_name='cosmos.tx.v1beta1.ModeInfo.single', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_MODEINFO_SINGLE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='sum', full_name='cosmos.tx.v1beta1.ModeInfo.sum',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=795,
  serialized_end=927,
)


_FEE = _descriptor.Descriptor(
  name='Fee',
  full_name='cosmos.tx.v1beta1.Fee',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='amount', full_name='cosmos.tx.v1beta1.Fee.amount', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\310\336\037\000\252\337\037(github.com/cosmos/cosmos-sdk/types.Coins', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gas_limit', full_name='cosmos.tx.v1beta1.Fee.gas_limit', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='payer', full_name='cosmos.tx.v1beta1.Fee.payer', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='granter', full_name='cosmos.tx.v1beta1.Fee.granter', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=930,
  serialized_end=1079,
)

_TX.fields_by_name['body'].message_type = _TXBODY
_TX.fields_by_name['auth_info'].message_type = _AUTHINFO
_TXBODY.fields_by_name['messages'].message_type = any__pb2._ANY
_TXBODY.fields_by_name['extension_options'].message_type = any__pb2._ANY
_TXBODY.fields_by_name['non_critical_extension_options'].message_type = any__pb2._ANY
_AUTHINFO.fields_by_name['signer_infos'].message_type = _SIGNERINFO
_AUTHINFO.fields_by_name['fee'].message_type = _FEE
_SIGNERINFO.fields_by_name['public_key'].message_type = any__pb2._ANY
_SIGNERINFO.fields_by_name['mode_info'].message_type = _MODEINFO
_MODEINFO_SINGLE.fields_by_name['mode'].enum_type = signing__pb2._SIGNMODE
_MODEINFO_SINGLE.containing_type = _MODEINFO
_MODEINFO.fields_by_name['single'].message_type = _MODEINFO_SINGLE
_MODEINFO.oneofs_by_name['sum'].fields.append(
  _MODEINFO.fields_by_name['single'])
_MODEINFO.fields_by_name['single'].containing_oneof = _MODEINFO.oneofs_by_name['sum']
_FEE.fields_by_name['amount'].message_type = coin__pb2._COIN
DESCRIPTOR.message_types_by_name['Tx'] = _TX
DESCRIPTOR.message_types_by_name['TxRaw'] = _TXRAW
DESCRIPTOR.message_types_by_name['SignDoc'] = _SIGNDOC
DESCRIPTOR.message_types_by_name['TxBody'] = _TXBODY
DESCRIPTOR.message_types_by_name['AuthInfo'] = _AUTHINFO
DESCRIPTOR.message_types_by_name['SignerInfo'] = _SIGNERINFO
DESCRIPTOR.message_types_by_name['ModeInfo'] = _MODEINFO
DESCRIPTOR.message_types_by_name['Fee'] = _FEE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Tx = _reflection.GeneratedProtocolMessageType('Tx', (_message.Message,), {
  'DESCRIPTOR' : _TX,
  '__module__' : 'tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.Tx)
  })
_sym_db.RegisterMessage(Tx)

TxRaw = _reflection.GeneratedProtocolMessageType('TxRaw', (_message.Message,), {
  'DESCRIPTOR' : _TXRAW,
  '__module__' : 'tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.TxRaw)
  })
_sym_db.RegisterMessage(TxRaw)

SignDoc = _reflection.GeneratedProtocolMessageType('SignDoc', (_message.Message,), {
  'DESCRIPTOR' : _SIGNDOC,
  '__module__' : 'tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.SignDoc)
  })
_sym_db.RegisterMessage(SignDoc)

TxBody = _reflection.GeneratedProtocolMessageType('TxBody', (_message.Message,), {
  'DESCRIPTOR' : _TXBODY,
  '__module__' : 'tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.TxBody)
  })
_sym_db.RegisterMessage(TxBody)

AuthInfo = _reflection.GeneratedProtocolMessageType('AuthInfo', (_message.Message,), {
  'DESCRIPTOR' : _AUTHINFO,
  '__module__' : 'tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.AuthInfo)
  })
_sym_db.RegisterMessage(AuthInfo)

SignerInfo = _reflection.GeneratedProtocolMessageType('SignerInfo', (_message.Message,), {
  'DESCRIPTOR' : _SIGNERINFO,
  '__module__' : 'tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.SignerInfo)
  })
_sym_db.RegisterMessage(SignerInfo)

ModeInfo = _reflection.GeneratedProtocolMessageType('ModeInfo', (_message.Message,), {

  'Single' : _reflection.GeneratedProtocolMessageType('Single', (_message.Message,), {
    'DESCRIPTOR' : _MODEINFO_SINGLE,
    '__module__' : 'tx_pb2'
    # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.ModeInfo.Single)
    })
  ,
  'DESCRIPTOR' : _MODEINFO,
  '__module__' : 'tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.ModeInfo)
  })
_sym_db.RegisterMessage(ModeInfo)
_sym_db.RegisterMessage(ModeInfo.Single)

Fee = _reflection.GeneratedProtocolMessageType('Fee', (_message.Message,), {
  'DESCRIPTOR' : _FEE,
  '__module__' : 'tx_pb2'
  # @@protoc_insertion_point(class_scope:cosmos.tx.v1beta1.Fee)
  })
_sym_db.RegisterMessage(Fee)


DESCRIPTOR._options = None
_FEE.fields_by_name['amount']._options = None
# @@protoc_insertion_point(module_scope)
